==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/PercentageVolumeOscillatorIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicatorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PercentageVolumeOscillatorIndicatorDescription, _super);
    function PercentageVolumeOscillatorIndicatorDescription() {
        var _this = _super.call(this) || this;
        _this.ec = 0;
        _this.eb = 0;
        return _this;
    }
    PercentageVolumeOscillatorIndicatorDescription.prototype.get_type = function () {
        return "PercentageVolumeOscillatorIndicator";
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicatorDescription.prototype, "shortPeriod", {
        get: function () {
            return this.ec;
        },
        set: function (a) {
            this.ec = a;
            this.e("ShortPeriod");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PercentageVolumeOscillatorIndicatorDescription.prototype, "longPeriod", {
        get: function () {
            return this.eb;
        },
        set: function (a) {
            this.eb = a;
            this.e("LongPeriod");
        },
        enumerable: true,
        configurable: true
    });
    PercentageVolumeOscillatorIndicatorDescription.$t = markType(PercentageVolumeOscillatorIndicatorDescription, 'PercentageVolumeOscillatorIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return PercentageVolumeOscillatorIndicatorDescription;
}(StrategyBasedIndicatorDescription));
export { PercentageVolumeOscillatorIndicatorDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/PercentageVolumeOscillatorIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicatorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PercentageVolumeOscillatorIndicatorDescription, _super);
    function PercentageVolumeOscillatorIndicatorDescription() {
        var _this = _super.call(this) || this;
        _this.gm = 0;
        _this.gl = 0;
        return _this;
    }
    PercentageVolumeOscillatorIndicatorDescription.prototype.get_type = function () {
        return "PercentageVolumeOscillatorIndicator";
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicatorDescription.prototype, "shortPeriod", {
        get: function () {
            return this.gm;
        },
        set: function (a) {
            this.gm = a;
            this.g("ShortPeriod");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PercentageVolumeOscillatorIndicatorDescription.prototype, "longPeriod", {
        get: function () {
            return this.gl;
        },
        set: function (a) {
            this.gl = a;
            this.g("LongPeriod");
        },
        enumerable: false,
        configurable: true
    });
    PercentageVolumeOscillatorIndicatorDescription.$t = markType(PercentageVolumeOscillatorIndicatorDescription, 'PercentageVolumeOscillatorIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return PercentageVolumeOscillatorIndicatorDescription;
}(StrategyBasedIndicatorDescription));
export { PercentageVolumeOscillatorIndicatorDescription };
